@@ -17,7 +17,7 @@ ELASTICSEARCH_INDEX = os.environ.get('ARCHELOND_ELASTICSEARCH_INDEX', None)
 
 # Load path to environment variable to point to htpasswd file
 # or write the ARCHELOND_HTPASSWD out to a file and ref that
-HTPASSWD_PATH = os.environ.get('ARCHELOND_HTPASSWD_PATH')
+HTPASSWD_PATH = os.environ.get('ARCHELOND_HTPASSWD_PATH', '.htpasswd')
 if os.environ.get('ARCHELOND_HTPASSWD'):
     HTPASSWD_PATH = os.path.abspath('.htpasswd')
     with open(HTPASSWD_PATH, 'w') as wfile:
